@@ -444,7 +444,7 @@ extern const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32];
     },
     {
         "???", "januari", "februari", "maart", "april", "mei", "juni",
-        "juli", "augustus", "september", "october", "november", "december"
+        "juli", "augustus", "september", "oktober", "november", "december"
     },
     {
         "???", "Gennaio", "Febbraio", "Marzo", "Aprile", "Maggio", "Giugno",
@@ -570,6 +570,7 @@ extern const N_char DateCalc_Day_of_Week_Abbreviation_[DateCalc_LANGUAGES+1][8][
         "", "", "", "", "", "", "", ""
     },
     {
+        "", "", "", "", "", "", "", ""
         "???", "2", "3", "4", "5", "6", "Sb", "Dom"
     },
     {
@@ -647,11 +648,12 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*  VERSION:  5.6                                                            */
+/*  VERSION:  5.7                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
+/*    Version 5.7  23.08.09  Fixed Dutch "oktober", Portuguese DOW abbrevs.  */
 /*    Version 5.6  28.07.09  Made the module MacOS X compatible.             */
 /*    Version 5.5  skipped due to an unauthorized upload by someone else.    */
 /*    Version 5.4  03.10.04  Added compiler directives for C++.              */
